@@ -1,6 +1,6 @@
 from abc import ABC, abstractmethod
 
-from instant_python.config.domain.config_schema import ConfigSchema
+from instant_python.shared.domain.config_schema import ConfigSchema
 
 
 class ConfigWriter(ABC):
