@@ -1,7 +1,6 @@
-{% set template_domain_import = "shared.domain"|compute_base_path(template.name) %}
 import json
 
-from {{ general.source_name }}.{{ template_domain_import }}.event.domain_event import DomainEvent
+from {{ general.source_name }}{{ "shared.domain.event.domain_event" | resolve_import_path(template.name) }} import DomainEvent
 
 
 class DomainEventJsonSerializer:
