@@ -1,12 +1,7 @@
-{% set template_domain_import = "shared.domain"|compute_base_path(template.name) %}
 {% if python_version in ["3.12", "3.13"] %}
 from abc import ABC, abstractmethod
 
-{% if template_domain_import %}
-from {{ general.source_name }}.{{ template_domain_import }}.event.domain_event import DomainEvent
-{% else %}
-from {{ general.source_name }}.event.domain_event import DomainEvent
-{% endif %}
+from {{ general.source_name }}{{ "shared.domain.event.domain_event" | resolve_import_path(template.name) }} import DomainEvent
 
 
 class DomainEventSubscriber[EventType: DomainEvent](ABC):
@@ -22,11 +17,7 @@ class DomainEventSubscriber[EventType: DomainEvent](ABC):
 from abc import ABC, abstractmethod
 from typing import Generic, TypeVar
 
-{% if template_domain_import %}
-from {{ general.source_name }}.{{ template_domain_import }}.event.domain_event import DomainEvent
-{% else %}
-from {{ general.source_name }}.event.domain_event import DomainEvent
-{% endif %}
+from {{ general.source_name }}{{ "shared.domain.event.domain_event" | resolve_import_path(template.name) }} import DomainEvent
 
 EventType = TypeVar("EventType", bound=DomainEvent)
 
