@@ -1,17 +1,9 @@
-{% set template_domain_import = "shared.domain"|compute_base_path(template.name) %}
 import re
 
-{% if template_domain_import %}
-from {{ general.source_name }}.{{ template_domain_import }}.event.domain_event import DomainEvent
-from {{ general.source_name }}.{{ template_domain_import }}.event.domain_event_subscriber import (
+from {{ general.source_name }}{{ "shared.domain.event.domain_event" | resolve_import_path(template.name) }} import DomainEvent
+from {{ general.source_name }}{{ "shared.domain.event.domain_event_subscriber" | resolve_import_path(template.name) }} import (
     DomainEventSubscriber,
 )
-{% else %}
-from {{ general.source_name }}.event.domain_event import DomainEvent
-from {{ general.source_name }}.event.domain_event_subscriber import (
-    DomainEventSubscriber,
-)
-{% endif %}
 
 
 class RabbitMqQueueFormatter:
