@@ -3,7 +3,7 @@ import tempfile
 
 import pytest
 import yaml
-from approvaltests import verify_all_combinations
+from approvaltests import verify_all_combinations, verify
 from typer.testing import CliRunner
 
 from instant_python.initialize.delivery.cli import app
@@ -12,7 +12,7 @@ from instant_python.shared.supported_licenses import SupportedLicenses
 from instant_python.shared.supported_managers import SupportedManagers
 from instant_python.shared.supported_python_versions import SupportedPythonVersions
 from instant_python.shared.supported_templates import SupportedTemplates
-from test.initialize.utils import resources_path
+from test.utils import resources_path
 
 
 @pytest.mark.acceptance
@@ -20,7 +20,7 @@ class TestInitCli:
     def setup_method(self) -> None:
         self._runner = CliRunner()
 
-    def test_initializes_project_with_general_section_combinations(self) -> None:
+    def test_should_initialize_project_with_general_section_combinations(self) -> None:
         dependency_managers = SupportedManagers.get_supported_managers()
         licenses = SupportedLicenses.get_supported_licenses()
         python_versions = SupportedPythonVersions.get_supported_versions()
@@ -34,7 +34,7 @@ class TestInitCli:
             ],
         )
 
-    def test_initializes_project_with_git_section_combinations(self) -> None:
+    def test_should_initialize_project_with_git_section_combinations(self) -> None:
         create_git_repository = [True, False]
 
         verify_all_combinations(
@@ -44,7 +44,7 @@ class TestInitCli:
             ],
         )
 
-    def test_initializes_project_with_template_section_combinations(self) -> None:
+    def test_should_initialize_project_with_template_section_combinations(self) -> None:
         templates = SupportedTemplates.get_supported_templates()
         built_in_features = SupportedBuiltInFeatures.get_supported_built_in_features()
 
@@ -56,7 +56,7 @@ class TestInitCli:
             ],
         )
 
-    def test_should_initializes_project_with_predefined_dependencies_and_different_managers(self) -> None:
+    def test_should_initialize_project_with_predefined_dependencies_and_different_managers(self) -> None:
         dependency_managers = SupportedManagers.get_supported_managers()
         predefined_dependencies = [
             {"name": "requests", "version": "latest", "is_dev": False, "group": ""},
@@ -71,6 +71,14 @@ class TestInitCli:
             ],
         )
 
+    def test_should_initialize_project_with_custom_project_structure(self) -> None:
+        verify(
+            self._run_cli_with_custom_template_config(
+                template=SupportedTemplates.CUSTOM.value,
+                custom_template_path=str(resources_path()),
+            )
+        )
+
     def _run_cli_with_general_config(
         self,
         dependency_manager: str,
@@ -122,6 +130,17 @@ class TestInitCli:
 
         return self._run_cli_with_config(config)
 
+    def _run_cli_with_custom_template_config(
+        self,
+        template: str,
+        custom_template_path: str,
+    ) -> dict:
+        config = json.loads(json.dumps(self._read_base_config()))
+
+        config["template"]["name"] = template
+
+        return self._run_cli_with_custom_config(config, custom_template_path)
+
     def _run_cli_with_config(self, config: dict) -> dict:
         with tempfile.NamedTemporaryFile(mode="w", suffix=".yml", delete=False) as config_file:
             yaml.dump(config, config_file)
@@ -135,6 +154,21 @@ class TestInitCli:
             "errors": result.exception,
         }
 
+    def _run_cli_with_custom_config(self, config: dict, custom_template_folder: str) -> dict:
+        with tempfile.NamedTemporaryFile(mode="w", suffix=".yml", delete=False) as config_file:
+            yaml.dump(config, config_file)
+            config_file_path = config_file.name
+
+        with self._runner.isolated_filesystem():
+            result = self._runner.invoke(
+                app, ["--config", str(config_file_path), "--templates", str(custom_template_folder)]
+            )
+
+        return {
+            "exit_code": result.exit_code,
+            "errors": result.exception,
+        }
+
     def _create_general_config(
         self,
         dependency_manager: str,
